      SUBROUTINE ZBKTP3 (ZLUN, ZBKNAM, IERR)
C-----------------------------------------------------------------------
C! clean up host environment at end of BAKTP
C# Z Tape
C-----------------------------------------------------------------------
C;  Copyright (C) 1995
C;  Associated Universities, Inc. Washington DC, USA.
C;
C;  This program is free software; you can redistribute it and/or
C;  modify it under the terms of the GNU General Public License as
C;  published by the Free Software Foundation; either version 2 of
C;  the License, or (at your option) any later version.
C;
C;  This program is distributed in the hope that it will be useful,
C;  but WITHOUT ANY WARRANTY; without even the implied warranty of
C;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C;  GNU General Public License for more details.
C;
C;  You should have received a copy of the GNU General Public
C;  License along with this program; if not, write to the Free
C;  Software Foundation, Inc., 675 Massachusetts Ave, Cambridge,
C;  MA 02139, USA.
C;
C;  Correspondence concerning AIPS should be addressed as follows:
C;         Internet email: aipsmail@nrao.edu.
C;         Postal address: AIPS Project Office
C;                         National Radio Astronomy Observatory
C;                         520 Edgemont Road
C;                         Charlottesville, VA 22903-2475 USA
C-----------------------------------------------------------------------
C-----------------------------------------------------------------------
C   Clean up host environment after BAKTP execution.
C   Inputs:
C      ZLUN     I       LUN for command file
C      ZBKNAM   C*(*)   Name of command file
C   Output:
C      IERR     I       Error code: 0 => okay, else ZSHCMD
C   Unix version - removes the command file
C-----------------------------------------------------------------------
      INTEGER   ZLUN, IERR
      CHARACTER ZBKNAM*(*)
C
      CHARACTER COMMND*40
      INTEGER   CLEN, ITRIM
      INCLUDE 'INCS:DMSG.INC'
C-----------------------------------------------------------------------
C                                       delete the command file:
      COMMND = 'rm ' // ZBKNAM
      CLEN = ITRIM (COMMND)
      CALL ZSHCMD (CLEN, COMMND, 8, 'TASK_OUT', IERR)
C
 999  RETURN
      END
